"""Version"""

__title__ = 'bsr'
__description__ = 'Tizen Build Statistics Reporter.'
__url__ = 'https://tizen.org'
__version__ = '0.0.6'
__build__ = 0x20210730
__author__ = 'Hyokeun Jeon'
__author_email__ = 'hyokeun.jeon@samsung.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2020 Samsung Research'
__cake__ = '\\u2728 \\U0001f370 \\u2728'
